@@ -1,6 +1,6 @@
  /**************************************************************************
- *   Copyright (C) 2006 by Danny Kukawka                                   *
- *                            <dkukawka@suse.de>, <danny.kukawka@web.de>   *
+ *   Copyright (C) 2006-2007 by Danny Kukawka                              *
+ *                           <dkukawka@suse.de>, <danny.kukawka@web.de>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of version 2 of the GNU General Public License     *
@@ -21,50 +21,56 @@
  * \file 	hardware_battery.cpp
  * \brief 	In this file can be found the Battery related code.
  * \author 	Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
- * \date    	2006
+ * \date    	2006-2007
  */
 
 #include "hardware_battery.h"
 
 /*! The default constructor of the class Battery. */
 Battery::Battery(dbusHAL* _dbus_HAL) : dbus_HAL(_dbus_HAL) {
-	myDebug("Battery:Battery( dbusHAL* )");
+	kdDebugFuncIn(trace);
 
 	udi = QString();
 	initialized = false;
 	
 	initDefault();
 	init(NULL);
+
+	kdDebugFuncOut(trace);
 }	
 
 /*! The default constructor of the class Battery. */ 
 Battery::Battery( dbusHAL* _dbus_HAL, QString _udi ) : dbus_HAL(_dbus_HAL), udi(_udi) {
-	myDebug("Battery::Battery(udi=%s)", udi.latin1());
+	if (trace) kdDebug() << funcinfo << "IN , udi: " << udi << endl;
 	
 	initialized = false;
 
 	initDefault();
 	init(NULL);
+
+	kdDebugFuncOut(trace);
 }
 
 /*! The default constructor of the class Battery. */
 Battery::Battery() {
-	myDebug ("Battery::Battery()");
+	kdDebugFuncIn(trace);
 	initialized = false;
 
 	initDefault();
 	udi = QString();
+
+	kdDebugFuncOut(trace);
 }
 
 /*! The default destructor of the class Battery. */
 Battery::~Battery() {
-	myDebug("Battery::~Battery");
+	kdDebugFuncIn(trace);
 
 }
 
 //! init a battery with default values
 void Battery::initDefault() {
-	myDebug("Battery::initDefault");
+	kdDebugFuncIn(trace);
 
 	present = false;
 	type = BAT_UNKNOWN;
@@ -83,35 +89,35 @@ void Battery::initDefault() {
 	warn_level = 12;
 	low_level = 7;
 	crit_level = 2;
+	
+	kdDebugFuncOut(trace);
 }
 
 //! initialize this battery object with values from HAL
 void Battery::init(dbusHAL* _dbus_HAL) {
-	myDebug("Battery::init");
+	kdDebugFuncIn(trace);
 
 	if (_dbus_HAL != NULL)
 		dbus_HAL = _dbus_HAL;
 
 	// read battery information from HAL
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-
 		//couldnt connect to HAL
 		state=BAT_HAL_ERROR;
 	} else {
-
 		if (resetUdi(udi)) {
 			//udi is valid
 			recheck(); //fills all values
-
 			//ready here for now
-
 		} else {
 			//udi is invalid or is no battery
 			state=BAT_HAL_ERROR;
-			myDebug("Warning: Battery::init cannot make use of udi %s", udi.latin1());
+			kdWarning() << "Warning: Battery::init cannot make use of udi " << udi << endl;
 		}
 	}
+
 	initialized = true;
+	kdDebugFuncOut(trace);
 }
 
 //! rechecks only minimalistic set properties
@@ -119,18 +125,20 @@ void Battery::init(dbusHAL* _dbus_HAL) {
 * Will only recheck properties regarding current battery states/levels.
 */
 void Battery::minRecheck() {
-	myDebug("Battery::minRecheck");
+	kdDebugFuncIn(trace);
 
 	//first check whether HAL is available
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
 		//grr... no luck
-		myDebug("Warning: Battery::recheck couldn't connect to HAL");
+		kdError() << "Battery::recheck couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return;
 	}
 
 	checkBatteryPresent();
 	if (!present) {
-		myDebug ("Warning: No need to update other properties, battery not present.");
+		kdDebug() << "No need to update other properties, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return;
 	} else {
 		checkCapacityState();
@@ -140,6 +148,8 @@ void Battery::minRecheck() {
 		checkChargeLevelRate();
 		checkRemainingTime();
 	}
+
+	kdDebugFuncOut(trace);
 }
 
 //! recheck all properties of the battery
@@ -148,19 +158,21 @@ void Battery::minRecheck() {
  * primary batteries in one object.
  */
 void Battery::recheck() {
-	myDebug("Battery::recheck");
+	kdDebugFuncIn(trace);
 
 	//first check whether HAL is available
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
 		//grr... no luck
-		myDebug("Warning: Battery::recheck couldn't connect to HAL");
+		kdError() << "Battery::recheck couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return;
 	}
 
 	checkBatteryPresent();
 	checkBatteryType();
 	if (!present) {
-		myDebug ("Warning: No need to update properties, battery not present.");
+		kdDebug() << "Warning: No need to update properties, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return;
 	} else {
 		checkBatteryTechnology();
@@ -174,6 +186,8 @@ void Battery::recheck() {
 		checkChargeLevelRate();
 		checkRemainingTime();
 	}
+
+	kdDebugFuncOut(trace);
 }
 
 // ---> query HAL for properties SECTION : START <----
@@ -186,12 +200,13 @@ void Battery::recheck() {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkBatteryPresent () {
-	myDebug ("Battery::checkBatteryPresent");
+	kdDebugFuncIn(trace);
 
 	bool _present = false;
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -222,11 +237,12 @@ bool Battery::checkBatteryPresent () {
 
 	} else {
 		//query was not successfull
-		myDebug("Warning: query of battery.present of %s was not successfull.", udi.latin1());
+		kdDebug() << "Query of battery.present of " << udi << " wasn't successfull." << endl;
 		//..but we assume its there try on
 		present = true;
 	}
 	
+	kdDebugFuncOut(trace);
 	return true;
 }
 
@@ -238,12 +254,13 @@ bool Battery::checkBatteryPresent () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkBatteryType () {
-	myDebug ("Battery::checkBatteryType");
+	kdDebugFuncIn(trace);
 	
 	QString tmp_qstring;
 
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -264,11 +281,13 @@ bool Battery::checkBatteryType () {
 			//anything else will currently be "UNKNOWN"
 			type = BAT_UNKNOWN;
 		}
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull
-		myDebug("Warning: query of battery.type of %s was not successfull.", udi.latin1());
+		kdWarning() << "Query of battery.type of " << udi << " was not successfull." << endl;
 		type = BAT_UNKNOWN;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -281,17 +300,19 @@ bool Battery::checkBatteryType () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkBatteryTechnology () {
-	myDebug ("Battery::checkBatteryTechnology");
+	kdDebugFuncIn(trace);
 	
 	QString tmp_qstring;
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -301,11 +322,12 @@ bool Battery::checkBatteryTechnology () {
 		} else {
 			technology = QString("UNKNOWN");
 		}
-
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull, but this property is optional
 		technology = QString("UNKNOWN");
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -319,26 +341,30 @@ bool Battery::checkBatteryTechnology () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkCapacityState () {
-	myDebug ("Battery::checkCapacityState");
+	kdDebugFuncIn(trace);
 
 	QString tmp_qstring;
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (dbus_HAL->halGetPropertyString(udi, "battery.charge_level.capacity_state", &tmp_qstring)) {
 		capacity_state = QString(tmp_qstring);
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull, but this property is optional
 		capacity_state = QString();
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -352,15 +378,17 @@ bool Battery::checkCapacityState () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkChargeLevelCurrent () {
-	myDebug ("Battery::checkChargeLevelCurrent");
+	kdDebugFuncIn(trace);
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -369,12 +397,13 @@ bool Battery::checkChargeLevelCurrent () {
 			//overflow?
 			charge_level_current = 0;
 		}
-
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull (is mandatory)
-		myDebug("Error: couldn't request charge_level.current for %s.", udi.latin1());
+		kdError() << "Couldn't request charge_level.current for udi: " << udi << endl;
 		state = BAT_NONE;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -388,15 +417,17 @@ bool Battery::checkChargeLevelCurrent () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkChargeLevelLastfull () {
-	myDebug ("Battery::checkChargeLevelLastfull");
+	kdDebugFuncIn(trace);
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -405,11 +436,13 @@ bool Battery::checkChargeLevelLastfull () {
 			//possible overflow?
 			charge_level_lastfull = charge_level_current;
 		}
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull (is mandatory)
-		myDebug("Error: couldn't query last_full of %s.", udi.latin1());
+		kdError() << "couldn't query last_full of udi: " << udi << endl;
 		charge_level_lastfull = 0; // set back to 0
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -422,15 +455,17 @@ bool Battery::checkChargeLevelLastfull () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkChargeLevelRate () {
-	myDebug ("Battery::checkChargeLevelRate");
+	kdDebugFuncIn(trace);
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError()  << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -443,11 +478,13 @@ bool Battery::checkChargeLevelRate () {
 		if (present_rate != _rate)
 			emit changedBattery();
 
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull but this is optional
-		myDebug("Warning: couldn't request charge_level.rate for %s.", udi.latin1());
+		kdError() << "Couldn't request charge_level.rate for udi: " <<  udi << endl;
 		present_rate = 0;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -461,23 +498,27 @@ bool Battery::checkChargeLevelRate () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkChargeLevelUnit () {
-	myDebug ("Battery::checkChargeLevelUnit");
+	kdDebugFuncOut(trace);
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!dbus_HAL->halGetPropertyString(udi, "battery.charge_level.unit", &charge_level_unit)) {
 		//query was not successfull but this is optional
-		myDebug("Warning: couldn't request charge_level.unit for %s.", udi.latin1());
+		kdWarning() << "Couldn't request charge_level.unit for udi: " << udi << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	} else {
+		kdDebugFuncOut(trace);
 		return true;
 	}
 }
@@ -490,15 +531,17 @@ bool Battery::checkChargeLevelUnit () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkChargeLevelDesign () {
-	myDebug ("Battery::checkChargeLevelDesign");
+	kdDebugFuncIn(trace);
 	
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -506,10 +549,12 @@ bool Battery::checkChargeLevelDesign () {
 		if (design_capacity < 0)
 			design_capacity = 0;
 
+		kdDebugFuncOut(trace);
 		return true;
 	} else {
 		//query was not successfull (is mandatory but not critical)
-		myDebug("Warning: couldn't request charge_level.design for %s.", udi.latin1());
+		kdWarning() << "Couldn't request charge_level.design for udi: " << udi << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 }
@@ -523,19 +568,21 @@ bool Battery::checkChargeLevelDesign () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkRemainingPercentage () {
-	myDebug ("Battery::checkRemainingPercentage");
+	kdDebugFuncIn(trace);
 	
 	bool ret = false;
 	int _val = 0;
 	int _state = -1;
 
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -550,11 +597,11 @@ bool Battery::checkRemainingPercentage () {
 		//query was not successfull, but this property is optional
 		//so we calculate it from charge_level
 		if (charge_level_current > 0) {
-			_val = (int)((charge_level_current * 100) / charge_level_lastfull);
+			_val = (int)((float)(charge_level_current * 100) / (float)charge_level_lastfull);
 			ret = true;
 		} else {
-			myDebug("Error: couldn't query percentage of %s. and charge_level_current >= 0",
-				 udi.latin1());
+			kdError() << "Couldn't query percentage of udi: " << udi 
+				  << ". and charge_level_current >= 0" << endl;
 		}
 	}
 
@@ -596,6 +643,7 @@ bool Battery::checkRemainingPercentage () {
 		state = _state;
 	}
 
+	kdDebugFuncOut(trace);
 	return ret;
 }
 
@@ -607,18 +655,20 @@ bool Battery::checkRemainingPercentage () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkRemainingTime () {
-	myDebug ("Battery::checkRemainingTime");
+	kdDebugFuncIn(trace);
 	
 	int _min = 0;
 	bool _ret = false;	
 
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -649,6 +699,7 @@ bool Battery::checkRemainingTime () {
 		remaining_minutes = _min;
 	}
 
+	kdDebugFuncOut(trace);
 	return _ret;
 }
 
@@ -660,7 +711,7 @@ bool Battery::checkRemainingTime () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::checkChargingState () {
-	myDebug ("Battery::checkChargingState");
+	kdDebugFuncIn(trace);
 	
 	bool tmp_bool = false;
 	bool tmp_bool2 = false;
@@ -668,12 +719,14 @@ bool Battery::checkChargingState () {
 	int _c_state = -1;
 
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
-		myDebug("Warning: couldn't connect to HAL");
+		kdError() << "Couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
 	if (!present) {
-		myDebug ("Warning: No need to update property, battery not present.");
+		kdWarning() << "No need to update property, battery not present." << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
 
@@ -689,7 +742,7 @@ bool Battery::checkChargingState () {
 		
 		_ret = true;
 	} else {
-		myDebug("Error: couldn't get current charging state for %s.", udi.latin1());
+		kdError() << "Couldn't get current charging state for udi: " << udi << endl;
 		_c_state = UNKNOWN_STATE;
 		_ret = false;
 	}
@@ -703,6 +756,7 @@ bool Battery::checkChargingState () {
 		charging_state = _c_state;
 	}
 
+	kdDebugFuncOut(trace);
 	return _ret;	
 }
 
@@ -719,52 +773,57 @@ bool Battery::checkChargingState () {
  * \retval false 	if the update couldn't be applied
  */
 bool Battery::updateProperty(QString _udi, QString _property) {
-	myDebug ("Battery::updateProperty");
+	kdDebugFuncIn(trace);
 	
 	//first check whether HAL is available
 	if (!dbus_HAL->isConnectedToHAL() && !dbus_HAL->reconnect()) {
 		//grr... no luck
-		myDebug("Warning: Battery::updateProperty couldn't connect to HAL");
+		kdError() << "Battery::updateProperty couldn't connect to HAL" << endl;
+		kdDebugFuncOut(trace);
 		return false;
 	}
+	
+	bool ret = true;
 
 	if (udi.startsWith(_udi)) {
 		// handle different keys and update only the needed
 		if (_property.startsWith("battery.present")) {
-			if (!checkBatteryPresent()) return false;
+			if (!checkBatteryPresent()) ret = false;
 		} else if (_property.startsWith("battery.type")) {
-			if (!checkBatteryType()) return false;
+			if (!checkBatteryType()) ret = false;
 		} else if (_property.startsWith("battery.charge_level.capacity_state")) {
-			if (!checkCapacityState()) return false;
+			if (!checkCapacityState()) ret=  false;
 		} else if (_property.startsWith("battery.charge_level.current")) {
-			if (!checkChargeLevelCurrent()) return false;
+			if (!checkChargeLevelCurrent()) ret = false;
 		} else if (_property.startsWith("battery.charge_level.rate")) {
-			if (!checkChargeLevelRate()) return false;
+			if (!checkChargeLevelRate()) ret = false;
 		} else if (_property.startsWith("battery.charge_level.percentage")) {
-			if (!checkRemainingPercentage()) return false;
+			if (!checkRemainingPercentage()) ret = false;
 		} else if (_property.startsWith("battery.remaining_time")) {
-			if (!checkRemainingTime()) return false;
+			if (!checkRemainingTime()) ret = false;
 		} else if (_property.startsWith("battery.rechargeable.is_")) {
-			if (!checkChargingState()) return false;
+			if (!checkChargingState()) ret = false;
 		} else if (_property.startsWith("battery.charge_level.last_full")) {
-			if (!checkChargeLevelLastfull()) return false;
+			if (!checkChargeLevelLastfull()) ret = false;
 	// --> changes on this keys should normally not happen except if battery was added /removed
 		} else if (_property.startsWith("battery.technology")) {
-			if (!checkBatteryTechnology()) return false;
+			if (!checkBatteryTechnology()) ret = false;
 		} else if (_property.startsWith("battery.charge_level.unit")) {
-			if (!checkChargeLevelUnit()) return false;
+			if (!checkChargeLevelUnit()) ret = false;
 		} else if (_property.startsWith("battery.charge_level.design")) {
-			if (!checkChargeLevelDesign()) return false;
+			if (!checkChargeLevelDesign()) ret = false;
 		} else {
-			myDebug("Unknown or unhandled device property: %s for device %s",
-				_property.latin1(), _udi.latin1());
+			kdDebug() << "Unknown or unhandled device property: " << _property 
+				  << " for device with udi: " << _udi << endl;
+			ret = false;
 		}
-
-		return true;
 	} else {
-		myDebug ("given UDI doesn't match the UDI of this battery object.");
-		return false;
+		kdError() << "Given UDI doesn't match the UDI of this battery object." << endl;
+		ret = false;
 	}
+
+	kdDebugFuncOut(trace);
+	return ret;
 }
 
 //! Resets the current HAL udi used by the one given
@@ -777,7 +836,8 @@ bool Battery::updateProperty(QString _udi, QString _property) {
 * \retval false 	if reset couldn't be applied
 */
 bool Battery::resetUdi(QString _udi) {
-	myDebug("Battery::resetUdi");
+	kdDebugFuncIn(trace);
+
 	bool tmp_result=false;
 
 	//trivial pre-check to eliminate totally dumb _udi strings
@@ -789,13 +849,14 @@ bool Battery::resetUdi(QString _udi) {
 			dbus_HAL->halQueryCapability(_udi,"battery",&tmp_result);
 
 		} else {
-			myDebug("Warning: Battery::resetUdi couldn't connect to HAL");
+			kdError() << "Battery::resetUdi couldn't connect to HAL" << endl;
 		}
 
 	} else {
-		myDebug("Warning: Battery::resetUdi received empty or invalid udi");
+		kdError() << "Battery::resetUdi received empty or invalid udi" << endl;
 	}
 
+	kdDebugFuncOut(trace);
 	return tmp_result;
 }
 
@@ -803,36 +864,45 @@ bool Battery::resetUdi(QString _udi) {
 
 //! sets the chargelevel in percent when battery should go into state warning
 void Battery::setWarnLevel(int _warn_level) {
-	myDebug("Battery::setWarnLevel");
+	kdDebugFuncIn(trace);
 
 	if (_warn_level < low_level) {
-		myDebug("Error: refuses %d as it is smaller than the LowLevel %d.", _warn_level, low_level);
+		kdError() << "Refuse requested level: " << _warn_level 
+			  << " as it is smaller than the LowLevel: " << low_level << endl;
 	} else {
 		warn_level = _warn_level;
 	}
+
+	kdDebugFuncOut(trace);
 }
 
 //! sets the chargelevel in percent when battery should go into state low
 void Battery::setLowLevel(int _low_level) {
-	myDebug("Battery::setLowLevel");
+	kdDebugFuncIn(trace);
 
 	if (_low_level < crit_level || _low_level > warn_level) {
-		myDebug("Error: refuses %d as it is not between WarnLevel %d and CritLevel %d.", 
-			_low_level, warn_level, crit_level);
+		kdError() << "Refuse requested level: " << _low_level 
+			  << " as it is not between WarnLevel: " << warn_level
+			  << " and CritLevel: " << crit_level << endl; 
 	} else {
 		low_level = _low_level;
 	}
+
+	kdDebugFuncOut(trace);
 }
 
 //! sets the chargelevel in percent when battery should go into state critical
 void Battery::setCritLevel(int _crit_level) {
-	myDebug("Battery::setCritLevel");
+	kdDebugFuncIn(trace);
 
 	if (_crit_level > low_level) {
-		myDebug("Error: refuses %d as it is bigger than LowLevel %d.", _crit_level, low_level);
+		kdError() << "Refuse requested level: " << _crit_level
+			  << " as it is bigger than LowLevel: " << low_level << endl;
 	} else {
 		crit_level = _crit_level;
 	}
+
+	kdDebugFuncOut(trace);
 }
 
 // ---> write private members SECTION : END <----
@@ -961,3 +1031,5 @@ bool Battery::isCritical() {
 }
  
 // ---> get private members SECTION : START <----
+
+#include "hardware_battery.moc"
