@@ -1,7 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2004 by  Thomas Renninger                               *
-*                            <trenn@suse.de> and                          *
-*                          Danny Kukawka                                  *
+*   Copyright (C)                                                         *
+*            2004-2007 by Danny Kukawka                                   *
 *                            <dkukawka@suse.de>, <danny.kukawka@web.de>   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -34,21 +33,36 @@
 // QT - Header
 #include <qdatetime.h>
 
+// KDE Header
+#include <kdebug.h>
+
 /*! 
 *  \file 	kpowersave_debug.h
 *  \brief 	Headerfile for debug releated defines/macros. Currently this file
 *		contains the myDebug(...) macro.
 */
 
-/* #define ENABLE_DEBUG_MSG_MODE 1 for debugging or call ./configure --enable-debug-msg */
-#ifdef ENABLE_DEBUG_MSG_MODE
-#define myDebug(x, y...) do {							\
-	fprintf(stderr, " %s:%d:\t", QTime::currentTime().toString().ascii(), 	\
-				   QTime::currentTime().msec());		\
-	qDebug(x, ## y);							\
+// to store the value over the different classes
+extern bool trace;
+
+/*
+ * macro to collect time and k_funcinfo information for kdDebug()
+ */
+#define funcinfo "[" << QTime::currentTime().toString().ascii() << 			\
+		 ":" << QTime::currentTime().msec() << "]" <<  k_funcinfo
+
+/*
+ * macros to trace function entry and leave points
+ */
+#define kdDebugFuncIn(traceinfo) do {							\
+	if (traceinfo == true)								\
+		kdDebug() << funcinfo << "IN " << endl;					\
 } while (0)
-#else
-#define myDebug(x, y...) do{} while(0)
-#endif 
+
+#define kdDebugFuncOut(traceinfo) do {							\
+	if (traceinfo == true) 								\
+		kdDebug() << funcinfo << "OUT " << endl;				\
+} while (0)
+
 
 #endif //_KPOWERSAVE_DEBUG_H
