@@ -1,13 +1,12 @@
 /**************************************************************************
 *   Copyright (C) 2004 by    Thomas Renninger                             *
 *                              <trenn@suse.de>                            *
-*                 2004-2006   Danny Kukawka                               *
+*                 2004-2007   Danny Kukawka                               *
 *                              <dkukawka@suse.de>, <danny.kukawka@web.de> *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
+*   it under the terms of version 2 of the GNU General Public License     *
+*   as published by the Free Software Foundation.                         *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -27,6 +26,8 @@
 #include <klocale.h>
 #include <kiconloader.h>
 
+#include "kpowersave_debug.h"
+
  /*! 
  *  \file 	main.cpp
  *  \brief 	The file with the \ref kdemain class to start kpowersave.
@@ -36,16 +37,17 @@
  *  \brief 	The kpowersave kdemain class, which is the startpoint of KPowersave.
  *  \author     Thomas Renninger, <trenn@suse.de>
  *  \author     Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
- *  \date       2004 - 2006
+ *  \date       2004 - 2007
  */
 
-static const char description[] = I18N_NOOP("KDE Frontend to powersave Package, "
-					    "Battery Monitor and General Power Management Support");
+static const char description[] = I18N_NOOP("KDE Frontend for Power Management, Battery Monitoring and Suspend");
 
-KCmdLineOptions options[] = { { "force-acpi-check", I18N_NOOP("Force a new check for ACPI support\n"), 0 },
+KCmdLineOptions options[] = { { "force-acpi-check", I18N_NOOP("Force a new check for ACPI support"), 0 },
+			      { "dbg-trace", I18N_NOOP("Trace function entry and leave points for debug\n"), 0 },	
 			      { 0, 0, 0 }};
 
-static const char version[] = "0.6.2";
+static const char version[] = "0.7.x (0.7.3)";
+bool trace = false;
 
 extern "C"
 int kdemain(int argc, char **argv)
@@ -57,7 +59,7 @@ int kdemain(int argc, char **argv)
 	about.addAuthor("Danny Kukawka", I18N_NOOP("Current maintainer"), "danny.kukawka@web.de" );
 	about.addAuthor("Thomas Renninger", 0, "trenn@suse.de" );
 	
-	about.addCredit("Holger Macht", I18N_NOOP("Powersave developer and for DBUS integration"), 
+	about.addCredit("Holger Macht", I18N_NOOP("Powersave developer and for D-Bus integration"), 
 			"hmacht@suse.de");
 	about.addCredit("Stefan Seyfried", I18N_NOOP("Powersave developer and tester"), 
 			"seife@suse.de");
@@ -83,11 +85,10 @@ int kdemain(int argc, char **argv)
 
 	kpowersave *mainWin = 0;
 
-	mainWin = new kpowersave(args->isSet( "force-acpi-check" ));
+	mainWin = new kpowersave(args->isSet( "force-acpi-check" ), args->isSet( "dbg-trace" ));
 	app.setMainWidget( mainWin );
 	mainWin->show();
 
 	// mainWin has WDestructiveClose flag by default, so it will delete itself.
 	return app.exec();
 }
-
