@@ -1,11 +1,10 @@
 /***************************************************************************
- *   Copyright (C) 2004 by Danny Kukawka                                   *
- *                         <dkukawka@suse.de>, <danny.kukawka@web.de>      *
+ *   Copyright (C) 2004-2006 by Danny Kukawka                              *
+ *                              <dkukawka@suse.de>, <danny.kukawka@web.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of version 2 of the GNU General Public License     *
+ *   as published by the Free Software Foundation.                         *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -25,11 +24,12 @@
  * All 'higher level' class members of the class screen can be found here: \ref screen 
  * \brief 	In this file can be found all screensaver related code. 
  * \author 	Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
- * \date    	2004
+ * \date    	2004 - 2006
  */
  
- 
+ // own headers
 #include "screen.h"
+#include "kpowersave_debug.h"
 
 /* needed for lXext C library linkage */
 extern "C" {
@@ -43,7 +43,10 @@ extern "C" {
 
 /*! The default constructor of the class screen */
 screen::screen() {
+	kdDebugFuncIn(trace);
+
 	xscreensaver_lock = NULL;
+	xscreensaver_reset = NULL;
 	gnomescreensaver_lock = NULL;
 	gnomeScreensaverCheck = NULL;
 	xlock = NULL;
@@ -59,19 +62,13 @@ screen::screen() {
 	connect( check_xscreensaver_timer, SIGNAL(timeout()), this, SLOT(xscreensaver_ping() ));
 
 	SCREENSAVER_STATUS = checkScreenSaverStatus();
-
-	// dummys for screen.cpp
-	QString dummy = "";
-	dummy = i18n("KScreensaver not found.");
-	dummy = i18n("Try locking with XScreensaver or xlock.");
-	dummy = i18n("XScreensaver not found.");
-	dummy = i18n("Try locking the screen with xlock.");
-	dummy = i18n("XScreensaver and xlock not found. It is not possible to lock the screen. Check your installation.");
-	
+	kdDebugFuncOut(trace);
 }
 
 /*! The default destructor of the class screen */
-screen::~screen() {}
+screen::~screen() {
+	kdDebugFuncIn(trace);
+}
 
 /*!
 * To enable/disable the KScreensaver/Xscreensaver.
@@ -81,12 +78,15 @@ screen::~screen() {}
 * \retval false if there is a error
 */
 bool screen::setScreenSaver(bool enable){
+	kdDebugFuncIn(trace);
+
 	if(SCREENSAVER_STATUS == -1) SCREENSAVER_STATUS = checkScreenSaverStatus();
 	if((SCREENSAVER_STATUS == 1) || (SCREENSAVER_STATUS == 0)){	
 		screen_save_dcop_ref.send( "enable", enable);
+		kdDebugFuncOut(trace);
 		return true;
-		
 	}
+
 	if(SCREENSAVER_STATUS == 11 || SCREENSAVER_STATUS == 10){
 		if(enable) {
 			check_xscreensaver_timer->stop();
@@ -96,9 +96,12 @@ bool screen::setScreenSaver(bool enable){
 			check_xscreensaver_timer->start( xScreenSaver_timer_interval );
 			check_xscreensaver_timer_runs = true;
 		}
+		kdDebugFuncOut(trace);
 		return true;	
+	} else {
+		kdDebugFuncOut(trace);
+		return false;
 	}
-	else return false;
 }
 
 
@@ -144,6 +147,8 @@ static int badwindow_handler(Display * dpy, XErrorEvent * error) {
 * \retval n ID of the founded XScreensaver window
 */
 static Window find_xscreensaver_window(Display * dpy) {
+	kdDebugFuncIn(trace);
+
 	Window root = RootWindowOfScreen(DefaultScreenOfDisplay(dpy));
 	Window root2, parent, *kids;
 	Window retval = 0;
@@ -154,7 +159,10 @@ static Window find_xscreensaver_window(Display * dpy) {
 	xs_version = XInternAtom(dpy, "_SCREENSAVER_VERSION", True);
 
 	if (!(xs_version != None && XQueryTree(dpy, root, &root2, &parent, &kids, &nkids) 
-		&& kids && nkids)) return 0;
+		&& kids && nkids)) {
+		kdDebugFuncOut(trace);
+		return 0;
+	}
 
 	defaultHandler = XSetErrorHandler(badwindow_handler);
 
@@ -177,6 +185,7 @@ static Window find_xscreensaver_window(Display * dpy) {
 	}
 	XFree(kids);
 	XSetErrorHandler(defaultHandler);
+	kdDebugFuncOut(trace);
 	return retval;
 }
 
@@ -189,6 +198,8 @@ static Window find_xscreensaver_window(Display * dpy) {
 * smaller then 1 minute (this is the smallest interval of Xscreensaver a.t.m.).
 */
 void screen::xscreensaver_ping(){
+	kdDebugFuncIn(trace);
+
 	if(!got_XScreensaver) {
 		mDisplay = qt_xdisplay();
 		xs_windowid = find_xscreensaver_window(mDisplay);
@@ -215,6 +226,8 @@ void screen::xscreensaver_ping(){
 		}
 		XSync(mDisplay, False);
 	}
+
+	kdDebugFuncOut(trace);
 }
 /*
  * END Section
@@ -231,6 +244,8 @@ void screen::xscreensaver_ping(){
 * \retval -1 else
 */
 int screen::checkScreenSaverStatus() {
+	kdDebugFuncIn(trace);
+	
 	bool get_reply = false;	
 	int kScreenSaver_tmp_status = -1;
 	int check = -1;
@@ -264,15 +279,19 @@ int screen::checkScreenSaverStatus() {
 	
 	// check for gnome-screen-saver
 	if (check == 10) {
-		if (gnomeScreensaverCheck != NULL)
-			delete gnomeScreensaverCheck;
+		delete gnomeScreensaverCheck;
 
 		gnomeScreensaverCheck = new KProcess;
 		*gnomeScreensaverCheck << "gnome-screensaver-command" << "--query";
 
 		connect( gnomeScreensaverCheck , SIGNAL(processExited(KProcess *)),SLOT(getGSExited(KProcess *)));
 		
-		if(!gnomeScreensaverCheck->start(KProcess::NotifyOnExit)) return 10;
+		if(!gnomeScreensaverCheck->start(KProcess::NotifyOnExit)) 
+		{
+			delete gnomeScreensaverCheck;
+			gnomeScreensaverCheck = NULL;
+			return 10;
+		}
 		else return 99;	
 	}
 
@@ -284,14 +303,19 @@ int screen::checkScreenSaverStatus() {
  * \param gnomecheckcommand the KPocess which called this SLOT
  */
 void screen::getGSExited (KProcess *gnomecheckcommand) {
+	kdDebugFuncIn(trace);
 
 	if (gnomecheckcommand->normalExit()){
 		if (gnomecheckcommand->exitStatus() == 1) SCREENSAVER_STATUS = 10;
 		else if (gnomecheckcommand->exitStatus() == 0) SCREENSAVER_STATUS = 20;
-	}
-	else
+	} else {
 		SCREENSAVER_STATUS = 10;
-	
+	}
+
+	delete gnomeScreensaverCheck;
+	gnomeScreensaverCheck=NULL;	
+
+	kdDebugFuncOut(trace);
 	return;
 } 
  
@@ -303,6 +327,8 @@ void screen::getGSExited (KProcess *gnomecheckcommand) {
 * \retval -1 if there is a error
 */
 int screen::checkDPMSStatus(){
+	kdDebugFuncIn(trace);
+
 	CARD16 state;
 	BOOL onoff;
 	int dummy;
@@ -311,14 +337,20 @@ int screen::checkDPMSStatus(){
 	
 	if (!DPMSQueryExtension(dpy, &dummy, &dummy) || !DPMSCapable(dpy)){
 		has_DPMS = false;
+		kdDebugFuncOut(trace);
 		return -1;
 	}
 	else
 		has_DPMS = true;
 	
 	DPMSInfo(dpy, &state, &onoff);
-	if(onoff) return 1;
-	else return 0;
+	if(onoff) {
+		kdDebugFuncOut(trace);
+		return 1;
+	} else {
+		kdDebugFuncOut(trace);
+		return 0;
+	}
 }
 
 
@@ -332,6 +364,8 @@ int screen::checkDPMSStatus(){
 *       \li check if DPMS-Settings correct set if DPMSEnable(dpy) used 
 */
 bool screen::setDPMS( bool enable ){	
+	kdDebugFuncIn(trace);
+
 	defaultHandler = XSetErrorHandler(badwindow_handler);
 
 	Display *dpy = qt_xdisplay();
@@ -340,6 +374,7 @@ bool screen::setDPMS( bool enable ){
 	if (!DPMSQueryExtension(dpy, &dummy, &dummy) || !DPMSCapable(dpy)){
 		has_DPMS = false;
 		XSetErrorHandler(defaultHandler);		
+		kdDebugFuncOut(trace);
 		return false;
 	}
 	
@@ -349,6 +384,7 @@ bool screen::setDPMS( bool enable ){
 	XFlush(dpy);
 	XSetErrorHandler(defaultHandler);
 	
+	kdDebugFuncOut(trace);
 	return true;
 }
 
@@ -362,6 +398,8 @@ bool screen::setDPMS( bool enable ){
 * \retval false if fail (DPMS not supported)
 */
 bool screen::setDPMSTimeouts( int standby_timeout, int suspend_timeout, int off_timeout){
+	kdDebugFuncIn(trace);
+
 	//XErrFunc defaultHandler;
 	defaultHandler = XSetErrorHandler(badwindow_handler);
 
@@ -371,6 +409,7 @@ bool screen::setDPMSTimeouts( int standby_timeout, int suspend_timeout, int off_
 	if (!DPMSQueryExtension(dpy, &dummy, &dummy) || !DPMSCapable(dpy)){
 		has_DPMS = false;
 		XSetErrorHandler(defaultHandler);		
+		kdDebugFuncOut(trace);
 		return false;
 	}
 	
@@ -378,6 +417,7 @@ bool screen::setDPMSTimeouts( int standby_timeout, int suspend_timeout, int off_
 	
 	XFlush(dpy);
 	XSetErrorHandler(defaultHandler);
+	kdDebugFuncOut(trace);
 	return true;
 }
 
@@ -389,45 +429,73 @@ bool screen::setDPMSTimeouts( int standby_timeout, int suspend_timeout, int off_
 * \retval false if there was a error
 */
 bool screen::lockScreen(){
+	kdDebugFuncIn(trace);
+
 	// screensaver status known?
 	if(SCREENSAVER_STATUS == -1) SCREENSAVER_STATUS = checkScreenSaverStatus();
 
 	// set lock for KScreensaver
 	if((SCREENSAVER_STATUS == 1) || (SCREENSAVER_STATUS == 0)){	
-		screen_save_dcop_ref.send("lock");
-		return true;
+		DCOPReply reply = screen_save_dcop_ref.call("lock");
+		if ( reply.isValid() ) {
+			return true;
+		} else {
+			kdWarning() << "Could not lock KScreensaver, try XScreensaver as fallback." << endl;
+			goto xscreensaver;
+		}
 	}
 	// set lock for XScreensaver
 	else if(SCREENSAVER_STATUS == 11){
-		if (xscreensaver_lock != NULL)
-			delete xscreensaver_lock;		
+xscreensaver:
+		delete xscreensaver_lock;		
 
 		xscreensaver_lock = new KProcess;
 		*xscreensaver_lock << "xscreensaver-command" << "-lock";
-		
-		return xscreensaver_lock->start(KProcess::DontCare);
+	        connect(xscreensaver_lock, SIGNAL(processExited(KProcess*)),
+	                this, SLOT(cleanProcess(KProcess*)));
+
+		bool status = xscreensaver_lock->start(KProcess::DontCare);
+		if(!status)
+		{
+			delete xscreensaver_lock;
+			xscreensaver_lock = NULL;
+		}
+		return status;
 	}
 	// lock with gnome-screen-saver
 	else if(SCREENSAVER_STATUS == 20){
-		if (gnomescreensaver_lock != NULL)
-			delete gnomescreensaver_lock;
+		delete gnomescreensaver_lock;
 
 		gnomescreensaver_lock = new KProcess;
 		*gnomescreensaver_lock << "gnome-screensaver-command" << "--lock";
-		
-		return gnomescreensaver_lock->start(KProcess::DontCare);
+	
+	        connect(gnomescreensaver_lock, SIGNAL(processExited(KProcess*)),
+	                this, SLOT(cleanProcess(KProcess*)));	
+		bool status = gnomescreensaver_lock->start(KProcess::DontCare);
+		if(!status)
+		{
+			delete gnomescreensaver_lock;
+			gnomescreensaver_lock=NULL;
+		}
+		return status;
 	}
 	// set lock for xlock --> no kscreensaver, no xscreensaver present and
 	// the check for gnome screensaver is not finished. This should normaly
 	// not happen, but in this case we use xlock
 	else if(SCREENSAVER_STATUS == 10 || SCREENSAVER_STATUS == 99){
-		if (xlock != NULL)
-			delete xlock;
+		delete xlock;
 		
 		xlock = new KProcess;
 		*xlock << "xlock"; //<< "-mode" << "blank";
-
-		return xlock->start(KProcess::DontCare);
+                connect(xlock, SIGNAL(processExited(KProcess*)),
+                           this, SLOT(cleanProcess(KProcess*)));
+		bool status = xlock->start(KProcess::DontCare);
+		if(!status)
+		{
+			delete xlock;
+			xlock = NULL;
+		}
+		return status;
 	}
 	else return false;
 }
@@ -442,23 +510,42 @@ bool screen::lockScreen(){
 * \todo check if we should also set blank only if the user would like!!!
 */
 bool screen::lockScreen( QString lock_withMethod ) {
+	kdDebugFuncIn(trace);
+
 	if (lock_withMethod == "automatic") {
 		lockScreen();
 		return true;
 	}
 	else if (lock_withMethod == "xlock") {
-		if (xlock != NULL)
-			delete xlock;
+		delete xlock;
 		
 		xlock = new KProcess;
 		*xlock << "xlock";
+                connect(xlock, SIGNAL(processExited(KProcess*)),
+                           this, SLOT(cleanProcess(KProcess*)));
 
-		return xlock->start(KProcess::DontCare);
+                bool status = xlock->start(KProcess::DontCare);
+		if(!status)
+		{
+			delete xlock;
+			xlock=NULL;
+		}
+
+		return status;
 	}
 	else if (lock_withMethod == "gnomescreensaver") {
 		gnomescreensaver_lock = new KProcess;
 		*gnomescreensaver_lock << "gnome-screensaver-command" << "--lock";
-		return gnomescreensaver_lock->start(KProcess::DontCare);
+                connect(gnomescreensaver_lock, SIGNAL(processExited(KProcess*)),
+                                                this, SLOT(cleanProcess(KProcess*)));
+
+		bool status = gnomescreensaver_lock->start(KProcess::DontCare);
+		if(!status)
+		{
+			delete gnomescreensaver_lock;
+			gnomescreensaver_lock = NULL;
+		}
+		return status;
 	}
 	else {
 		// screensaver status known?
@@ -466,20 +553,34 @@ bool screen::lockScreen( QString lock_withMethod ) {
 		
 		if (lock_withMethod == "kscreensaver") {
 			if((SCREENSAVER_STATUS == 1) || (SCREENSAVER_STATUS == 0)){	
-				screen_save_dcop_ref.send("lock");
-				return true;
+				DCOPReply reply = screen_save_dcop_ref.call("lock");
+				if ( reply.isValid() ) {
+					return true;
+				} else {
+					kdWarning() << "Could not call lock for KScreensaver, try XScreensaver "
+						    << "as fallback." << endl;
+					goto xscreensaver;
+				}
 			}
 			else return false;
 		}
 		else if (lock_withMethod == "xscreensaver") {
 			if(SCREENSAVER_STATUS == 11){
-				if (xscreensaver_lock != NULL)
-					delete xscreensaver_lock; 
+xscreensaver:
+				delete xscreensaver_lock; 
 				
 				xscreensaver_lock = new KProcess;
 				*xscreensaver_lock << "xscreensaver-command" << "-lock";
-			
-				return xscreensaver_lock->start(KProcess::DontCare);
+		                connect(xscreensaver_lock, SIGNAL(processExited(KProcess*)),
+                                                this, SLOT(cleanProcess(KProcess*)));
+
+				bool status = xscreensaver_lock->start(KProcess::DontCare);
+				if(!status)
+				{
+					delete xscreensaver_lock;
+					xscreensaver_lock = NULL;
+				}
+				return status;
 			}
 			else return false;
 		}
@@ -494,6 +595,8 @@ bool screen::lockScreen( QString lock_withMethod ) {
 * \todo find a way to set the xscreensaver to 'blank only'
 */
 void screen::blankOnlyScreen( bool blankonly ){
+	kdDebugFuncIn(trace);
+
 	if(SCREENSAVER_STATUS == -1) SCREENSAVER_STATUS = checkScreenSaverStatus();
 	// set KScreensaver
 	if((SCREENSAVER_STATUS == 1) || (SCREENSAVER_STATUS == 0)){	
@@ -503,16 +606,96 @@ void screen::blankOnlyScreen( bool blankonly ){
 	else if(SCREENSAVER_STATUS == 11){
 		// implement something !!!
 	}
+
+	kdDebugFuncOut(trace);
+}
+
+/*!
+* Use this function to reset the KDE screensaver/DPMS settings
+* \return boolean with the result of the operation
+* \retval true if the reset was called
+* \retval false if there was a error
+*/
+bool screen::resetKDEScreensaver(){
+	kdDebugFuncIn(trace);
+
+	if(SCREENSAVER_STATUS == -1) 
+		SCREENSAVER_STATUS = checkScreenSaverStatus();
+
+	// do this only if the screensaver is not running
+	if(SCREENSAVER_STATUS == 0){	
+		DCOPReply reply = screen_save_dcop_ref.call("configure");
+		if ( reply.isValid() ) {
+			kdDebugFuncOut(trace);
+			return true;
+		} else {
+			kdWarning() << "Could not call configure() for the KDE screensaver." << endl;
+			kdDebugFuncOut(trace);
+			return false;
+		}
+	} else {
+		kdDebugFuncOut(trace);
+		return false;
+	}
+}
+
+/*!
+* Use this function to reset the xscreensaver settings
+* \return boolean with the result of the operation
+* \retval true if the reset was called
+* \retval false if there was a error
+*/
+bool screen::resetXScreensaver(){
+	kdDebugFuncIn(trace);
+
+	if(checkScreenSaverStatus() == 11) {
+		
+		delete xscreensaver_reset;		
+
+		xscreensaver_reset = new KProcess;
+		*xscreensaver_reset << "xscreensaver-command" << "-restart";
+	        connect(xscreensaver_reset, SIGNAL(processExited(KProcess*)),
+	                this, SLOT(cleanProcess(KProcess*)));
+
+		bool status = xscreensaver_reset->start(KProcess::DontCare);
+		if(!status)
+		{
+			delete xscreensaver_reset;
+			xscreensaver_reset = NULL;
+		}
+		kdDebugFuncOut(trace);
+		return status;
+	} else {
+		kdDebugFuncOut(trace);
+		return false;
+	}
 }
 
 /*!
 * function to call xset commandline tool to force shutdown the display with dpms
 */
 void screen::forceDPMSOff() {
+	kdDebugFuncIn(trace);
 	
 	KProcess *xset = new KProcess;
 	*xset << "xset" << "dpms" << "force" << "off";
-	xset->start();
+        connect(xset, SIGNAL(processExited(KProcess*)),
+                this, SLOT(cleanProcess(KProcess*)));
+	if(!xset->start())
+	{
+		delete xset;
+	}
+
+	kdDebugFuncOut(trace);
+}
+
+/*!
+ * function to clean KProcess objects
+ */
+void screen::cleanProcess(KProcess* proc)
+{
+	delete proc;
+	proc = NULL;
 }
 
 /*!
@@ -520,7 +703,8 @@ void screen::forceDPMSOff() {
 * passwd dialog after suspend if we locked the screen.
 */
 void screen::fakeShiftKeyEvent() {
-	
+	kdDebugFuncIn(trace);
+
 	Display *dpy = qt_xdisplay();
 
 	if (dpy) {
@@ -530,5 +714,8 @@ void screen::fakeShiftKeyEvent() {
 		XFlush(dpy);
 	}
 
+	kdDebugFuncOut(trace);
 	return;
 }
+
+#include "screen.moc"
